# Social-Phi
A python package to calculate temporal integrated information of a group of people based on their temporal activites as time series. 
This was part of my bachelor thesis on unified behavioral analysis of social network users. Our main focus was on analysis of github repositories. We found out that the integrated information of a project (calculated based on contributers commits and with the help of the social_phi package) is correlated with other metrics of the project like number of stars, forks, issues, etc.

## Installation
```
git clone https://github.com/s-omranpour/Social-Phi
cd Social-Phi
pip install .
```

## Usage
You can see our case study and collected data in the examples directory. Notebooks contain the results used in my thesis.
